Currently in development
Technology based on the following Proceeding
title: Automated directed fairness testing},
author: Udeshi, Sakshi and Arora, Pryanshu and Chattopadhyay, Sudipta
booktitle: Proceedings of the 33rd ACM/IEEE International Conference on Automated Software Engineering,
pages: 98--108
year: 2018
Liscened by the original author